@@ -114,19 +114,16 @@ class tespy_fluid:
     0.0
 
     >>> v_tespy = v_mix_pT(fluid_props, T2)
-    >>> fluid_props_CP = [0, p, 0, {'air': 1}]
     >>> v = v_mix_pT(fluid_props_CP, T2)
     >>> round(abs(v_tespy - v) / v, 2)
     0.0
 
     >>> s_tespy = s_mix_pT(fluid_props, T2) - s_mix_pT(fluid_props, T1)
-    >>> fluid_props_CP = [0, p, 0, {'air': 1}]
     >>> s = s_mix_pT(fluid_props_CP, T2) - s_mix_pT(fluid_props_CP, T1)
     >>> round(abs(s_tespy - s) / s, 2)
     0.0
 
     >>> visc_tespy = visc_mix_pT(fluid_props, T2)
-    >>> fluid_props_CP = [0, p, 0, {'air': 1}]
     >>> visc = visc_mix_pT(fluid_props_CP, T2)
     >>> round(abs(visc_tespy - visc) / visc, 2)
     0.0
@@ -304,11 +301,12 @@ class memorise:
     r"""Memorization of fluid properties."""
 
     @staticmethod
-    def add_fluids(fluids):
+    def add_fluids(fluids, memorise_fluid_properties=True):
         r"""
         Add list of fluids to fluid memorisation class.
 
-        - Generate arrays for fluid property lookup.
+        - Generate arrays for fluid property lookup if memorisation is
+          activated.
         - Calculate/set fluid property value ranges for convergence checks.
 
         Parameters
@@ -317,6 +315,10 @@ class memorise:
             Dict of fluid and corresponding CoolProp back end for fluid
             property memorization.
 
+        memorise_fluid_properties : bool
+            Activate or deactivate fluid property value memorisation. Default
+            state is activated (:code:`True`).
+
         Note
         ----
         The memorise class creates globally accessible variables for different
@@ -346,22 +348,14 @@ class memorise:
         """
         # number of fluids
         num_fl = len(fluids)
-        if num_fl > 0:
+        if memorise_fluid_properties is True and num_fl > 0:
             fl = tuple(fluids.keys())
             # fluid property tables
-            memorise.T_ph[fl] = np.empty((0, num_fl + 3), float)
-            memorise.T_ps[fl] = np.empty((0, num_fl + 4), float)
-            memorise.v_ph[fl] = np.empty((0, num_fl + 3), float)
-            memorise.visc_ph[fl] = np.empty((0, num_fl + 3), float)
-            memorise.s_ph[fl] = np.empty((0, num_fl + 3), float)
-            # lists for memory cache, values not in these lists will be deleted
-            # from the table after every tespy.networks.network.solve call.
-            memorise.T_ph_f[fl] = []
-            memorise.T_ps_f[fl] = []
-            memorise.v_ph_f[fl] = []
-            memorise.visc_ph_f[fl] = []
-            memorise.s_ph_f[fl] = []
-            memorise.count = 0
+            memorise.T_ph[fl] = np.empty((0, num_fl + 4), float)
+            memorise.T_ps[fl] = np.empty((0, num_fl + 5), float)
+            memorise.v_ph[fl] = np.empty((0, num_fl + 4), float)
+            memorise.visc_ph[fl] = np.empty((0, num_fl + 4), float)
+            memorise.s_ph[fl] = np.empty((0, num_fl + 4), float)
 
             msg = 'Added fluids ' + str(fl) + ' to memorise lookup tables.'
             logging.debug(msg)
@@ -461,47 +455,43 @@ class memorise:
             List of fluid for fluid property memorization.
         """
         fl = tuple(fluids)
+        threshold = 3
+        try:
+            # delete memory
+            memorise.s_ph[fl] = memorise.s_ph[fl][
+                memorise.s_ph[fl][:, -1] > threshold]
+            memorise.s_ph[fl][:, -1] = 0
 
-        # delete memory
-        mask = np.isin(memorise.T_ph[fl][:, -1], memorise.T_ph_f[fl])
-        memorise.T_ph[fl] = (memorise.T_ph[fl][mask])
+            memorise.T_ph[fl] = memorise.T_ph[fl][
+                memorise.T_ph[fl][:, -1] > threshold]
+            memorise.T_ph[fl][:, -1] = 0
 
-        mask = np.isin(memorise.T_ps[fl][:, -1], memorise.T_ps_f[fl])
-        memorise.T_ps[fl] = (memorise.T_ps[fl][mask])
+            memorise.T_ps[fl] = memorise.T_ps[fl][
+                memorise.T_ps[fl][:, -1] > threshold]
+            memorise.T_ps[fl][:, -1] = 0
 
-        mask = np.isin(memorise.v_ph[fl][:, -1], memorise.v_ph_f[fl])
-        memorise.v_ph[fl] = (memorise.v_ph[fl][mask])
+            memorise.v_ph[fl] = memorise.v_ph[fl][
+                memorise.v_ph[fl][:, -1] > threshold]
+            memorise.v_ph[fl][:, -1] = 0
 
-        mask = np.isin(memorise.visc_ph[fl][:, -1], memorise.visc_ph_f[fl])
-        memorise.visc_ph[fl] = (memorise.visc_ph[fl][mask])
+            memorise.visc_ph[fl] = memorise.visc_ph[fl][
+                memorise.visc_ph[fl][:, -1] > threshold]
+            memorise.visc_ph[fl][:, -1] = 0
 
-        mask = np.isin(memorise.s_ph[fl][:, -1], memorise.s_ph_f[fl])
-        memorise.s_ph[fl] = (memorise.s_ph[fl][mask])
-
-        # refresh cache
-        memorise.T_ph_f[fl] = []
-        memorise.T_ps_f[fl] = []
-        memorise.v_ph_f[fl] = []
-        memorise.visc_ph_f[fl] = []
-        memorise.s_ph_f[fl] = []
-
-        msg = ('Dropping not frequently used fluid property values from '
-               'memorise class for fluids ' + str(fl) + '.')
-        logging.debug(msg)
+            msg = ('Dropping not frequently used fluid property values from '
+                   'memorise class for fluids ' + str(fl) + '.')
+            logging.debug(msg)
+        except KeyError:
+            pass
 
 
 # create memorise dictionaries
 memorise.state = {}
 memorise.T_ph = {}
-memorise.T_ph_f = {}
 memorise.T_ps = {}
-memorise.T_ps_f = {}
 memorise.v_ph = {}
-memorise.v_ph_f = {}
 memorise.visc_ph = {}
-memorise.visc_ph_f = {}
 memorise.s_ph = {}
-memorise.s_ph_f = {}
 memorise.value_range = {}
 
 # %%
@@ -542,28 +532,25 @@ def T_mix_ph(flow, T0=300):
     fl = tuple(flow[3].keys())
     memorisation = fl in memorise.T_ph.keys()
     if memorisation is True:
-        a = memorise.T_ph[fl][:, :-1]
+        a = memorise.T_ph[fl][:, :-2]
         b = np.array([flow[1], flow[2]] + list(flow[3].values()))
         ix = np.where(np.all(abs(a - b) <= err, axis=1))[0]
 
         if ix.size == 1:
             # known fluid properties
-            T = memorise.T_ph[fl][ix, -1][0]
-            memorise.T_ph_f[fl] += [T]
-            return T
+            memorise.T_ph[fl][ix, -1] += 1
+            return memorise.T_ph[fl][ix, -2][0]
 
     # unknown fluid properties
     fluid = single_fluid(flow[3])
     if fluid is None:
         # calculate the fluid properties for fluid mixtures
-        if memorisation is True:
-            valmin = max(
-                [memorise.value_range[f][2] for f in fl if flow[3][f] > err]
-            ) + 0.1
-            if T0 < valmin or np.isnan(T0):
-                T0 = valmin * 1.1
-        else:
-            valmin = 70
+        valmin = max(
+            [memorise.value_range[f][2] for f in fl if flow[3][f] > err]
+        ) + 0.1
+        if T0 < valmin or np.isnan(T0):
+            T0 = valmin * 1.1
+
         val = newton(h_mix_pT, dh_mix_pdT, flow, flow[2], val0=T0,
                      valmin=valmin, valmax=3000, imax=10)
     else:
@@ -572,7 +559,8 @@ def T_mix_ph(flow, T0=300):
 
     if memorisation is True:
         # memorise the newly calculated value
-        new = np.asarray([[flow[1], flow[2]] + list(flow[3].values()) + [val]])
+        new = np.asarray(
+            [[flow[1], flow[2]] + list(flow[3].values()) + [val, 0]])
         memorise.T_ph[fl] = np.append(memorise.T_ph[fl], new, axis=0)
 
     return val
@@ -743,91 +731,66 @@ def T_mix_ps(flow, s, T0=300):
     fl = tuple(flow[3].keys())
     memorisation = fl in memorise.T_ps.keys()
     if memorisation is True:
-        a = memorise.T_ps[fl][:, :-1]
+        a = memorise.T_ps[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()) + [s])
         ix = np.where(np.all(abs(a - b) <= err, axis=1))[0]
         if ix.size == 1:
             # known fluid properties
-            T = memorise.T_ps[fl][ix, -1][0]
-            memorise.T_ps_f[fl] += [T]
-            return T
+            memorise.T_ps[fl][ix, -1] += 1
+            return memorise.T_ps[fl][ix, -2][0]
 
     # unknown fluid properties
     fluid = single_fluid(flow[3])
     if fluid is None:
         # calculate the fluid properties for fluid mixtures
-        if memorisation is True:
-            valmin = max(
-                [memorise.value_range[f][2] for f in fl if flow[3][f] > err]
-            ) + 0.1
-            if T0 < valmin or np.isnan(T0):
-                T0 = valmin * 1.1
-        else:
-            valmin = 70
+        valmin = max(
+            [memorise.value_range[f][2] for f in fl if flow[3][f] > err]
+        ) + 0.1
+        if T0 < valmin or np.isnan(T0):
+            T0 = valmin * 1.1
 
         val = newton(s_mix_pT, ds_mix_pdT, flow, s, val0=T0,
                      valmin=valmin, valmax=3000, imax=10)
-        if memorisation is True:
-            new = np.asarray(
-                [[flow[1], flow[2]] + list(flow[3].values()) + [s, val]])
-            # memorise the newly calculated value
-            memorise.T_ps[fl] = np.append(memorise.T_ps[fl], new, axis=0)
 
-        return val
     else:
         # calculate fluid property for pure fluids
-        msg = ('The calculation of temperature from pressure and entropy '
-               'for pure fluids should not be required, as the '
-               'calculation is always possible from pressure and '
-               'enthalpy. If there is a case, where you need to calculate '
-               'temperature from these properties, please inform us: '
-               'https://github.com/oemof/tespy.')
-        logging.error(msg)
-        raise ValueError(msg)
+        val = T_ps(flow[1], s, fluid)
 
-# %% deprecated
-#            for fluid, x in flow[3].items():
-#                if x > err:
-#                    val = T_ps(flow[1], s, fluid)
-#                    new = np.array([[flow[1], flow[2]] +
-#                                   list(flow[3].values()) + [s, val]])
-#                    # memorise the newly calculated value
-#                    memorise.T_ps[fl] = np.append(memorise.T_ps[fl],
-#                                                  new, axis=0)
-#                    return val
-#
-#
-# def T_ps(p, s, fluid):
-#     r"""
-#     Calculate the temperature from pressure and entropy for a pure fluid.
-#
-#     Parameters
-#     ----------
-#     p : float
-#        Pressure p / Pa.
-#
-#     s : float
-#        Specific entropy h / (J/(kgK)).
-#
-#     fluid : str
-#        Fluid name.
-#
-#     Returns
-#     -------
-#     T : float
-#        Temperature T / K.
-#     """
-#     if 'IDGAS::' in fluid:
-#         msg = 'Ideal gas calculation not available by now.'
-#         logging.warning(msg)
-#     if 'TESPy::' in fluid:
-#         db = tespy_fluid.fluids[fluid].funcs['s_pT']
-#         return newton(reverse_2d, reverse_2d_deriv, [db, p, s], 0)
-#     elif 'INCOMP::' in fluid:
-#         return CPPSI('T', 'P', p, 'H', s, fluid)
-#     else:
-#         memorise.state[fluid].update(CP.PSmass_INPUTS, p, s)
-#         return memorise.state[fluid].T()
+    if memorisation is True:
+        new = np.asarray(
+            [[flow[1], flow[2]] + list(flow[3].values()) + [s, val, 0]])
+        # memorise the newly calculated value
+        memorise.T_ps[fl] = np.append(memorise.T_ps[fl], new, axis=0)
+
+    return val
+
+
+def T_ps(p, s, fluid):
+    r"""
+    Calculate the temperature from pressure and entropy for a pure fluid.
+
+    Parameters
+    ----------
+    p : float
+       Pressure p / Pa.
+
+    s : float
+       Specific entropy h / (J/(kgK)).
+
+    fluid : str
+       Fluid name.
+
+    Returns
+    -------
+    T : float
+       Temperature T / K.
+    """
+    if fluid in tespy_fluid.fluids.keys():
+        db = tespy_fluid.fluids[fluid].funcs['s_pT']
+        return newton(reverse_2d, reverse_2d_deriv, [db, p, s], 0)
+    else:
+        memorise.state[fluid].update(CP.PSmass_INPUTS, p, s)
+        return memorise.state[fluid].T()
 
 # %%
 
@@ -1157,14 +1120,13 @@ def v_mix_ph(flow, T0=300):
     fl = tuple(flow[3].keys())
     memorisation = fl in memorise.v_ph.keys()
     if memorisation is True:
-        a = memorise.v_ph[fl][:, :-1]
+        a = memorise.v_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
         ix = np.where(np.all(abs(a - b) <= err, axis=1))[0]
         if ix.size == 1:
             # known fluid properties
-            v = memorise.v_ph[fl][ix, -1][0]
-            memorise.v_ph_f[fl] += [v]
-            return v
+            memorise.v_ph[fl][ix, -1] += 1
+            return memorise.v_ph[fl][ix, -2][0]
 
     # unknown fluid properties
     fluid = single_fluid(flow[3])
@@ -1177,7 +1139,8 @@ def v_mix_ph(flow, T0=300):
 
     if memorisation is True:
         # memorise the newly calculated value
-        new = np.asarray([[flow[1], flow[2]] + list(flow[3].values()) + [val]])
+        new = np.asarray(
+            [[flow[1], flow[2]] + list(flow[3].values()) + [val, 0]])
         memorise.v_ph[fl] = np.append(memorise.v_ph[fl], new, axis=0)
 
     return val
@@ -1327,14 +1290,19 @@ def v_mix_pT(flow, T):
 
     .. math::
 
-        v_{mix}(p,T)=\sum_{i} \frac{x_i}{\rho(p, T, fluid_{i})}
+        v_{mix}(p,T)=\frac{1}{\sum_{i} \rho(pp_{i}, T, fluid_{i})}\;
+        \forall i \in \text{fluid components}\\
+        pp: \text{partial pressure}
     """
-    v = 0
+    n = molar_mass_flow(flow[3])
+
+    d = 0
     for fluid, x in flow[3].items():
         if x > err:
-            v += x / d_pT(flow[1], T, fluid)
+            ni = x / molar_masses[fluid]
+            d += d_pT(flow[1] * ni / n, T, fluid)
 
-    return v
+    return 1 / d
 
 
 def d_mix_pT(flow, T):
@@ -1426,14 +1394,13 @@ def visc_mix_ph(flow, T0=300):
     fl = tuple(flow[3].keys())
     memorisation = fl in memorise.visc_ph.keys()
     if memorisation is True:
-        a = memorise.visc_ph[fl][:, :-1]
+        a = memorise.visc_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
         ix = np.where(np.all(abs(a - b) <= err, axis=1))[0]
         if ix.size == 1:
             # known fluid properties
-            visc = memorise.visc_ph[fl][ix, -1][0]
-            memorise.visc_ph_f[fl] += [visc]
-            return visc
+            memorise.visc_ph[fl][ix, -1] += 1
+            return memorise.visc_ph[fl][ix, -2][0]
 
     # unknown fluid properties
     fluid = single_fluid(flow[3])
@@ -1446,7 +1413,8 @@ def visc_mix_ph(flow, T0=300):
 
     if memorisation is True:
         # memorise the newly calculated value
-        new = np.asarray([[flow[1], flow[2]] + list(flow[3].values()) + [val]])
+        new = np.asarray(
+            [[flow[1], flow[2]] + list(flow[3].values()) + [val, 0]])
         memorise.visc_ph[fl] = np.append(memorise.visc_ph[fl], new, axis=0)
     return val
 
@@ -1588,14 +1556,13 @@ def s_mix_ph(flow, T0=300):
     fl = tuple(flow[3].keys())
     memorisation = fl in memorise.s_ph.keys()
     if memorisation is True:
-        a = memorise.s_ph[fl][:, :-1]
+        a = memorise.s_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
         ix = np.where(np.all(abs(a - b) <= err, axis=1))[0]
         if ix.size == 1:
             # known fluid properties
-            s = memorise.s_ph[fl][ix, -1][0]
-            memorise.s_ph_f[fl] += [s]
-            return s
+            memorise.s_ph[fl][ix, -1] += 1
+            return memorise.s_ph[fl][ix, -2][0]
 
     # unknown fluid properties
     fluid = single_fluid(flow[3])
@@ -1608,7 +1575,8 @@ def s_mix_ph(flow, T0=300):
 
     if memorisation is True:
         # memorise the newly calculated value
-        new = np.asarray([[flow[1], flow[2]] + list(flow[3].values()) + [val]])
+        new = np.asarray(
+            [[flow[1], flow[2]] + list(flow[3].values()) + [val, 0]])
         memorise.s_ph[fl] = np.append(memorise.s_ph[fl], new, axis=0)
 
     return val
