@@ -13,3 +13,10 @@ err = 1e-6
 molar_masses = {}
 gas_constants = {}
 gas_constants['uni'] = 8.3144598
+# Define colors for highlighting values in result table
+coloring = {
+    'end': '\033[0m',
+    'set': '\033[94m',
+    'err': '\033[31m',
+    'var': '\033[32m'
+}
