@@ -32,7 +32,6 @@ from tespy.tools.characteristics import load_custom_char
 from tespy.tools.data_containers import data_container
 from tespy.tools.data_containers import dc_cc
 from tespy.tools.data_containers import dc_flu
-from tespy.tools.fluid_properties import T_mix_ps
 from tespy.tools.fluid_properties import h_mix_pQ
 from tespy.tools.fluid_properties import memorise
 from tespy.tools.fluid_properties import tespy_fluid
@@ -720,8 +719,3 @@ def test_IF97_back_end():
 def test_h_mix_pQ_on_mixtures():
     with raises(ValueError):
         h_mix_pQ([0, 0, 0, {'O2': 0.24, 'N2': 0.76}], 0.75)
-
-
-def test_T_mix_ps_on_pure_fluids():
-    with raises(ValueError):
-        T_mix_ps([0, 0, 0, {'O2': 1}], 1e3)
